pub struct ChannelSendRequestResponse {
pub response: Vec<u8>,
}Fields
response: Vec<u8>Trait Implementations
Sourceimpl Clone for ChannelSendRequestResponse
impl Clone for ChannelSendRequestResponse
Sourcefn clone(&self) -> ChannelSendRequestResponse
fn clone(&self) -> ChannelSendRequestResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChannelSendRequestResponse
impl Debug for ChannelSendRequestResponse
Sourceimpl<'a, ___E> Encode<ChannelSendRequestResponse<'static>, ___E> for &'a ChannelSendRequestResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ChannelSendRequestResponse<'static>, ___E> for &'a ChannelSendRequestResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSendRequestResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSendRequestResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ChannelSendRequestResponse<'static>, ___E> for ChannelSendRequestResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ChannelSendRequestResponse<'static>, ___E> for ChannelSendRequestResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSendRequestResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSendRequestResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ChannelSendRequestResponse<'static>>, ___E> for &'a ChannelSendRequestResponsewhere
___E: Encoder + ?Sized,
&'a ChannelSendRequestResponse: Encode<ChannelSendRequestResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ChannelSendRequestResponse<'static>>, ___E> for &'a ChannelSendRequestResponsewhere
___E: Encoder + ?Sized,
&'a ChannelSendRequestResponse: Encode<ChannelSendRequestResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a ChannelSendRequestResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ChannelSendRequestResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ChannelSendRequestResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ChannelSendRequestResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ChannelSendRequestResponse<'static>>, ___E> for ChannelSendRequestResponsewhere
___E: Encoder + ?Sized,
ChannelSendRequestResponse: Encode<ChannelSendRequestResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ChannelSendRequestResponse<'static>>, ___E> for ChannelSendRequestResponsewhere
___E: Encoder + ?Sized,
ChannelSendRequestResponse: Encode<ChannelSendRequestResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<ChannelSendRequestResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ChannelSendRequestResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ChannelSendRequestResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ChannelSendRequestResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ChannelSendRequestResponse<'de>> for ChannelSendRequestResponse
impl<'de> FromWire<ChannelSendRequestResponse<'de>> for ChannelSendRequestResponse
Sourcefn from_wire(
wire: ChannelSendRequestResponse<'de>,
) -> ChannelSendRequestResponse
fn from_wire( wire: ChannelSendRequestResponse<'de>, ) -> ChannelSendRequestResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ChannelSendRequestResponse<'de>> for ChannelSendRequestResponse
impl<'de> FromWireRef<ChannelSendRequestResponse<'de>> for ChannelSendRequestResponse
Sourcefn from_wire_ref(
wire: &ChannelSendRequestResponse<'de>,
) -> ChannelSendRequestResponse
fn from_wire_ref( wire: &ChannelSendRequestResponse<'de>, ) -> ChannelSendRequestResponse
Converts the given reference to this type.
Sourceimpl Hash for ChannelSendRequestResponse
impl Hash for ChannelSendRequestResponse
Sourceimpl Ord for ChannelSendRequestResponse
impl Ord for ChannelSendRequestResponse
Sourcefn cmp(&self, other: &ChannelSendRequestResponse) -> Ordering
fn cmp(&self, other: &ChannelSendRequestResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChannelSendRequestResponse
impl PartialEq for ChannelSendRequestResponse
Sourcefn eq(&self, other: &ChannelSendRequestResponse) -> bool
fn eq(&self, other: &ChannelSendRequestResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ChannelSendRequestResponse
impl PartialOrd for ChannelSendRequestResponse
impl Eq for ChannelSendRequestResponse
impl StructuralPartialEq for ChannelSendRequestResponse